@@ -1,17 +1,11 @@
 package Hub::Parse::Template;
-
-#-------------------------------------------------------------------------------
-# Copyright (c) 2006 Livesite Networks, LLC.  All rights reserved.
-# Copyright (c) 2000-2005 Ryan Gies.  All rights reserved.
-#-------------------------------------------------------------------------------
-
-#line 2
 use strict;
 
 use Hub qw/:lib/;
 
-our $VERSION        = '3.01048';
-our @ISA            = qw/Hub::Base::Object/;
+push our @ISA, qw/Hub::Base::Object/;
+
+our $VERSION        = '4.00012';
 our @EXPORT         = qw//;
 our @EXPORT_OK      = qw//;
 
@@ -22,15 +16,10 @@ our @EXPORT_OK      = qw//;
 # ------------------------------------------------------------------------------
 
 sub refresh {
-
     my ($self,$opts) = Hub::objopts( \@_ );
-
     my $spec = shift;
-
     $self->{'parser'} = mkinst( 'FileParser', $spec );
-
     Hub::merge( $self->{'public:'}, @_ ) if @_;
-
 }#refresh
 
 # ------------------------------------------------------------------------------
@@ -40,19 +29,12 @@ sub refresh {
 # ------------------------------------------------------------------------------
 
 sub comptv {
-
     my ($self,$opts) = Hub::objopts( \@_ );
-
     my ($k,$template) = (shift,shift);
-
     map {
-
         my $template = Hub::mkinst( 'Template', $template, $_ );
-
         Hub::happendv( $self->{'public:'}, $k, $template, '-asa=1' );
-
     } @_;
-
 }#comptv
 
 # ------------------------------------------------------------------------------
@@ -62,23 +44,15 @@ sub comptv {
 # ------------------------------------------------------------------------------
 
 sub compfv {
-
     my ($self,$opts) = Hub::objopts( \@_ );
-
     my ($k,$format) = (shift,shift);
-
     map {
-
         my $template = {
-
             'text'  => $format,
             'value' => $_,
         };
-
         Hub::happendv( $self->{'public:'}, $k, $template, '-asa=1' );
-
     } @_;
-
 }#compfv
 
 # ------------------------------------------------------------------------------
@@ -88,13 +62,9 @@ sub compfv {
 # ------------------------------------------------------------------------------
 
 sub compdv {
-
     my ($self,$opts) = Hub::objopts( \@_ );
-
     my $k = shift;
-
     map { Hub::happendv( $self->{'public:'}, $k, $_, '-asa=1' ) } @_;
-
 }#compdv
 
 # ------------------------------------------------------------------------------
@@ -104,14 +74,10 @@ sub compdv {
 # ------------------------------------------------------------------------------
 
 sub populate {
-
     my ($self,$opts) = Hub::objopts( \@_ );
-
     return $self->{'parser'}->populate(
         $self->{'public:'}, @_, -opts => $opts );
-
 }#populate
 
 # ------------------------------------------------------------------------------
-
-'???';
+1;
